<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Kérjük jelentkezzen be a Deepin® Azonosítójával</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>A további műveletek folytatásához be kell jelentkeznie.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Túl sok kérést nyújtott be, Kérjük próbálja újra később.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>A további műveletek folytatásához be kell jelentkeznie.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Hálózati hiba, kérjük próbálja meg később</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Nincs bejelentkezve</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Visszajelzéseim</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Bejelentkezés</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 megtekintés</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Levétel a kedvencekről</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Ösztönzés törlése</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Ösztönzés</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Hamarosan</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Hivatalos válasz</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Fajta:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Legújabb</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Ösztönzés</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Kommunikáció</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Beszélgessenek és osszák meg itt</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Hibajelentés küldése</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Jelentse a hibákat, amelyeket talál</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Küldje be javaslatait</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Források</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Kérdőív</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Csatlakozzon hozzánk</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Belső tesztelés</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation>Közösségi Hírek</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Nincs több elem</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Üzenetek</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Kérdőívek</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Indítsa el a rendszer indításakor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin® Központ</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Gyors bejelentkezés a fórumokba, javaslatok benyújtása és hibák bejelentése.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Nincsenek üzenetek</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 üzenet</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Összes megjelölése olvasottként</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Továbbiak megtekintése</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Hálózati hiba, próbálja meg később</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin® Központ</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Nincsenek kérdőívek.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Kitöltési idő: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Kitöltés</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>A további műveletek folytatásához be kell jelentkeznie.</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Reprodukálás</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Megerősítve</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Megválaszolva</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Megoldva</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Értékelés</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Elfogadva</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Befejezve</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>A probléma feldolgozása nem történt meg, és nem jelenik meg a nyilvános listán.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Jelenleg nem lehet azonosítani az okot; folyamatos ellenőrzésre és vizsgálatra van szükség.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>A probléma megismételhető, és a kiváltó ok azonosítva.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>A probléma nem hiba vagy más jellegű probléma.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>A probléma megoldva, javítva, és hivatalos kiadásra vár.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>A követelmény feldolgozása nem történt meg, és nem jelenik meg a nyilvános listán.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>A problémát elismerték, és belső értékelés alatt áll.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>A jövőbeni kiadás tervei között szerepel.</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>A követelményt vagy nem fogadták el, vagy nem lehet teljesíteni.</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>A fejlesztői munka befejeződött, hivatalos megjelenésre vár. </translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>A képernyőkép hozzáadása sikertelen.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>A képfájl mérete 1 MB-nál kisebb lehet.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>A képfájl formátuma nem támogatott a feltöltéshez.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[A termék jelenlegi állapota]: 
[Kívánt termék]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Előfeltételek]: 
[Reprodukálási lépések]: 
[Várható eredmények]: 
[Jelenlegi eredmények]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Visszajelzés küldése</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Javaslatok</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Hibajelentés küldése</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Cím:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Kérjük röviden írja le az észlelt problémát</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Tartalom:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Ne töltsön fel több hibajelzést egy visszajelzésben</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Ne töltsön ki több követelményt egy visszajelzésben</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Kérjük adja meg az e-mail címét</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Rendszer verzió:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Eszköz információ:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation> &lt;a href=&apos;home://sysinfo&apos;&gt;Eszköz információ feltöltése&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Képernyőkép:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Kép fájlok</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Fájlok húzásával, vagy a gombra kattintva adhat hozzá képeket (legfeljebb hármat). </translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Biztosan kilép a visszajelzés küldéséből?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>A visszajelzés tartalma nem kerül mentésre.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Küldés</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>A visszajelzés küldése sikertelen.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Kérjük, adja meg visszajelzésének címét, és tartalmát.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Kérjük, adja meg visszajelzésének címét.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Kérjük, adja meg visszajelzésének tartalmát.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Érvénytelen E-mail cím került megadásra.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Eszköz információ</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Visszajelzési központ</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Visszajelzéseim</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Ösztönzéseim</translation>
    </message>
</context>
</TS>